@@ -207,7 +207,7 @@ classification.tsn <- function(id, callopts = list(), return_id = TRUE, ...) {
     } else {
       out <- getfullhierarchyfromtsn(x, callopts, ...)
       # remove overhang
-      out <- out[1:which(out$tsn == x), c('taxonName', 'rankName', 'tsn')]
+      out <- out[1:which(out$tsn == x), c('taxonname', 'rankname', 'tsn')]
       names(out) <- c('name', 'rank', 'id')
       # Optionally return tsn of lineage
       if (!return_id) out <- out[, c('name', 'rank')]
@@ -393,7 +393,7 @@ classification.nbnid <- function(id, callopts = list(), return_id = TRUE, ...) {
       if (is(out, "simpleError")) {
         NA
       } else {
-        out <- out[ , c('name','rank', 'taxonVersionKey')]
+        out <- out[ , c('name','rank', 'taxonversionkey')]
         names(out) <- c('name', 'rank', 'id')
         # Optionally return id of lineage
         if (!return_id) out <- out[, c('name', 'rank')]
