@@ -12,7 +12,9 @@
 #' See \code{\link[taxize]{get_uid_}} to get back all, or a subset, of the raw data that you are
 #' presented during the ask process.
 #' @param modifier (character) A modifier to the \code{sciname} given. Options include:
-#' Organism, Scientific Name, Common Name, All Names, and more.
+#' Organism, Scientific Name, Common Name, All Names, Division, Filter, Lineage, GC,
+#' MGC, Name Tokens, Next Level, PGC, Properties, Rank, Subtree, Synonym, Text Word.
+#' These are not checked, so make sure they are entered correctly, as is.
 #' @param rank_query (character) A taxonomic rank name to modify the query sent to NCBI.
 #' See \code{\link{rank_ref}} for possible options. Though note
 #' that some data sources use atypical ranks, so inspect the data itself for options.
@@ -49,6 +51,14 @@
 #' use regex strings since we use \code{\link{grep}} internally to match.
 #' Filtering narrows down to the set that matches your query, and removes the rest.
 #'
+#' @section Beware:
+#' NCBI does funny things sometimes. E.g., if you search on Fringella morel, a slight
+#' misspelling of the genus name, and a non-existent epithet, NCBI gives back a morel
+#' fungal species. In addition, NCBI doesn't really do fuzzy searching very well, so if
+#' there is a slight mis-spelling in your names, you likely won't get what you are
+#' expecting. The lesson: clean your names before using this function. Other data
+#' sources are better about fuzzy matching.
+#'
 #' @seealso \code{\link[taxize]{get_tsn}}, \code{\link[taxize]{classification}}
 #'
 #' @export
@@ -303,14 +313,16 @@ get_uid_help <- function(sciname, verbose, rows){
   mssg(verbose, "\nRetrieving data for taxon '", sciname, "'\n")
   url <- paste("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=taxonomy&term=",
                gsub(" ", "+", sciname), sep = "")
-  xml_result <- xmlParse(content(GET(url)))
+  xml_result <- xmlParse(content(GET(url), "text"))
   Sys.sleep(0.33)
   uid <- xpathSApply(xml_result, "//IdList/Id", xmlValue)
-  if (length(uid) == 0) { NULL } else {
+  if (length(uid) == 0) {
+    NULL
+  } else {
     baseurl <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=taxonomy"
     ID <- paste("ID=", paste(uid, collapse = ","), sep = "")
     url <- paste(baseurl, ID, sep = "&")
-    tt <- content(GET(url))
+    tt <- content(GET(url), "text")
     ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
     df <- parse_ncbi(ttp)
     sub_rows(df, rows)
