@@ -25,7 +25,6 @@
 #'
 #' gbif_ping()
 #' gbif_ping(200)
-#' ubio_ping()
 #'
 #' bold_ping()
 #' bold_ping(200)
@@ -118,16 +117,6 @@ gbif_ping <- function(what = "status", ...) {
          content = grepl("1", content(res)$key, ignore.case = TRUE))
 }
 
-#' @export
-#' @rdname ping
-ubio_ping <- function(what = "status", ...) {
-  res <- GET("http://www.ubio.org/webservices/service.php?function=namebank_object&namebankID=2483153&keyCode=b052625da5f330e334471f8efe725c07bf4630a6", ...)
-  switch(matchwhat(what),
-         status = match_status(res),
-         code = match_code(res, what),
-         content = grepl("2483153", xpathApply(content(res), "//namebankID", xmlValue)[[1]], ignore.case = TRUE))
-}
-
 #' @export
 #' @rdname ping
 bold_ping <- function(what = "status", ...) {
@@ -178,3 +167,11 @@ match_code <- function(x, y){
   stopifnot(is(x, "response"))
   x$status_code == y
 }
+
+#' uBio ping
+#'
+#' @export
+#' @rdname ubio_ping-defunct
+ubio_ping <- function() {
+  .Defunct(msg = "the uBio API is down, for good as far as we know")
+}
