@@ -6,11 +6,13 @@
 #'    taxon identifier (e.g. 861)
 #' @param format (character) One of json (default) or xml.
 #' @param raw (logical) If TRUE, raw json or xml returned, if FALSE, parsed data returned.
-#' @param callopts (list) Further args passed on to htt::GET.
+#' @param ... (list) Further args passed on to htt::GET.
 #' @author Scott Chamberlain {myrmecocystus@@gmail.com}
 #' @return json, xml or a list.
 #' @references API docs http://data.canadensys.net/vascan/api
 #' @keywords names taxonomy
+#' @details Note that we lowercase all outputs in data.frame's, but when a list is
+#' given back, we don't touch the list names.
 #' @examples \dontrun{
 #' vascan_search(q = "Helianthus annuus")
 #' vascan_search(q = "Helianthus annuus", raw=TRUE)
@@ -30,23 +32,27 @@
 #' # lots of names, in this case 50
 #' splist <- names_list(rank='species', size=50)
 #' vascan_search(q = splist)
+#'
+#' # Curl options
+#' library("httr")
+#' vascan_search(q = "Helianthus annuus", config = verbose())
 #' }
-vascan_search <- function(q, format='json', raw=FALSE, callopts=list())
-{
+vascan_search <- function(q, format='json', raw=FALSE, ...) {
+
   url <- sprintf("http://data.canadensys.net/vascan/api/0.1/search.%s", format)
-  if(!length(q) > 1){
-    args <- list(q=q)
-    tt <- GET(url, query=args, callopts)
+  if (!length(q) > 1) {
+    tt <- GET(url, query = list(q = q), ...)
     stop_for_status(tt)
-    out <- content(tt, as="text")
-  } else
-  {
-    args <- paste(q, collapse='\n')
-    tt <- POST(url, body=list(q=args), encode='form')
+    out <- content(tt, as = "text")
+  } else {
+    args <- paste(q, collapse = '\n')
+    tt <- POST(url, body = list(q = args), encode = 'form', ...)
     stop_for_status(tt)
-    out <- content(tt, as="text")
+    out <- content(tt, as = "text")
   }
-  if(raw){ return( out ) } else {
+  if (raw) {
+    return( out )
+  } else {
     tmp <- jsonlite::fromJSON(out, FALSE)
     res <- tmp$results[[1]]
     lapply(tmp$results, vascan_parse)
@@ -54,15 +60,16 @@ vascan_search <- function(q, format='json', raw=FALSE, callopts=list())
 }
 
 vascan_parse <- function(x){
-  parsed <- lapply(x$matches, function(x){
-    taxass <- data.frame(x$taxonomicAssertions, stringsAsFactors = FALSE)
-    dist <- data.frame(rbindlist(x$distribution))
-    vern <- data.frame(rbindlist(x$vernacularNames))
-    list(taxonomicassertions=taxass, distribution=dist, vernacularnames=vern)
+  parsed <- lapply(x$matches, function(y) {
+    taxass <- nmslwr(data.frame(y$taxonomicAssertions, stringsAsFactors = FALSE))
+    dist <- nmslwr(data.frame(rbindlist(y$distribution)))
+    vern <- nmslwr(data.frame(rbindlist(y$vernacularNames)))
+    list(taxonomicassertions = taxass, distribution = dist, vernacularnames = vern)
   })
-  if(length(parsed) == 0){
-    data.frame(searchedterm=x$searchedTerm, nummatches=x$numMatches, matches=NA)
+  if (length(parsed) == 0) {
+    nmslwr(data.frame(searchedterm = x$searchedTerm, nummatches = x$numMatches,
+                      matches = NA, stringsAsFactors = FALSE))
   } else {
-    list(searchedterm=x$searchedTerm, nummatches=x$numMatches, matches=parsed)
+    list(searchedterm = x$searchedTerm, nummatches = x$numMatches, matches = parsed)
   }
 }
